Module vsmtp_rule_engine::api

Module containing the backend for the vsl’s Rust API.

Modules

  • Authentication systems.
  • Default return codes exposed by vsmtp.
  • backend for DKIM functionality.
  • backend for DMARC functionality.
  • API to interact with the DNS.
  • Functions used to change the content of the envelop.
  • API to write of the message on disk.
  • Log a message of level in the app target, which will be written to the the fie you specified in the field app.logs.filename form the vsmtp_config::Config.
  • Extensions for the MailContext type.
  • Extensions for the MessageBody type.
  • Default network ranges exposed by vsmtp.
  • backend for SPF functionality.
  • State Engine & filtering backend.
  • Functions to get date and time.
  • API for the delivery methods.
  • Utility functions.

Enums

  • vSL object type implementation. Objects are rust’s representation of rule engine variables. multiple types are supported.

Functions

Type Definitions

  • Alias for ctx()
  • Error produced by the vsl’s Rust API function calls.
  • Alias for msg()
  • Alias for srv()
  • vSL object type implementation. A vSL object that is shared or not, depending of the context of the rule engine.