Log a message of level in the app target, which will be written to the the fie you specified in the field app.logs.filename form the vsmtp_config::Config.

Functions

  • Log information to stdout in nodaemon mode or to a file.