Module vsmtp_rule_engine::api::message
Extensions for the MessageBody type.
Functions
- Add a recipient to the
Toheader of the message. - Add a new header at the end of the header list in the message.
- Count the number of headers with the given name.
- Get a list of all headers.
- Get a specific header from the incoming message.
- Get a list of all headers of a specific name with it’s name and value separated by a column.
- Checks if the message contains a specific header.
- Get a copy of the whole email as a string.
- Add a new header on top all other headers in the message.
- Remove an existing header from the message.
- Remove a recipient from the
Toheader of the message. - Replace an existing header name by a new value.
- Change the sender’s address in the
Fromheader of the message. - Replace a recipient by an other in the
Toheader of the message. - Replace an existing header value by a new value, or append a new header to the message.
- Generate the
.emlrepresentation of the message.