Type Definition vsmtp_rule_engine::api::SharedObject
pub type SharedObject = Arc<Object>;Expand description
vSL object type implementation.
A vSL object that is shared or not, depending of the context of the rule engine.
pub type SharedObject = Arc<Object>;vSL object type implementation.
A vSL object that is shared or not, depending of the context of the rule engine.